@@ -31,7 +31,7 @@ if TYPE_CHECKING:
 
     from airflow.utils.context import Context
 
-    MessageCallback = Callable[[ServiceBusMessage], None]
+    MessageCallback = Callable[[ServiceBusMessage, Context], None]
 
 
 class AzureServiceBusCreateQueueOperator(BaseOperator):
@@ -176,6 +176,7 @@ class AzureServiceBusReceiveMessageOperator(BaseOperator):
         # Receive message
         hook.receive_message(
             self.queue_name,
+            context,
             max_message_count=self.max_message_count,
             max_wait_time=self.max_wait_time,
             message_callback=self.message_callback,
@@ -562,6 +563,7 @@ class ASBReceiveSubscriptionMessageOperator(BaseOperator):
         hook.receive_subscription_message(
             self.topic_name,
             self.subscription_name,
+            context,
             self.max_message_count,
             self.max_wait_time,
             message_callback=self.message_callback,
